@@ -43,7 +43,8 @@ FEEDS = {
            'hasnulls': True,# can contain nulls
            'convertallstrings': False,# convert all values to string. recommended for compatibility reasons, conversion to native types is suggested as part of the ingestion in the processing platform
            'writeindex': False, # write index as extra column
-            'rowgroupoffset': 50000000, # offset row groups
+           'objectencoding': 'infer', # schema of data
+           'rowgroupoffset': 50000000, # offset row groups
            'items_rowgroup': 10000  # how many items per rowgroup, should be several thousands, e.g. between 5,000 and 30,000. The more rows the higher the memory consumption and the better the compression on the final parquet file
         },
     }
@@ -61,6 +62,7 @@ FEEDS = {
            'hasnulls': True,# can contain nulls
            'convertallstrings': False,# convert all values to string. recommended for compatibility reasons, conversion to native types is suggested as part of the ingestion in the processing platform
            'writeindex': False, # write index as extra column
+           'objectencoding': 'infer', # schema of data
            'rowgroupoffset': 50000000, # offset row groups
            'items_rowgroup': 10000  # how many items per rowgroup, should be several thousands, e.g. between 5,000 and 30,000. The more rows the higher the memory consumption and the better the compression on the final parquet file
         },
@@ -277,6 +279,7 @@ class ParquetItemExporter(BaseItemExporter):
         # Read settings
         self.pq_compression=options.pop('compression','GZIP')
         self.pq_times=options.pop('times','int64')
+        self.pq_objectencoding=options.pop('objectencoding','infer')
         self.pq_convertstr=options.pop('convertallstrings',False)
         self.pq_hasnulls=options.pop('hasnulls',True)
         self.pq_writeindex=options.pop('writeindex',False)
@@ -294,7 +297,7 @@ class ParquetItemExporter(BaseItemExporter):
         if self.itemcount>self.pq_items_rowgroup:
             self._flush_table()
         # Add the item to data frame
-        self.df=self.df.append(self._get_df_from_item(item),ignore_index=True)
+        self.df=pd.concat([self.df, self._get_df_from_item(item)])
         self.itemcount+=1
         return item
 
@@ -350,7 +353,7 @@ class ParquetItemExporter(BaseItemExporter):
                 row[column]=value
         if self.pq_convertstr==True:
           return pd.DataFrame(row,index=    [0]).astype(str)
-        return row
+        return pd.DataFrame.from_dict([row])
 
     def _reset_rowgroup(self):
         """
@@ -377,7 +380,7 @@ class ParquetItemExporter(BaseItemExporter):
             if self.firstBlock==True:
                 self.firstBlock=False
                 papp=False
-            fp_write(self.file.name, self.df,append=papp,compression=self.pq_compression,has_nulls=self.pq_hasnulls,write_index=self.pq_writeindex,file_scheme="simple",object_encoding="infer",times=self.pq_times,row_group_offsets=self.pq_rowgroupoffset)
+            fp_write(self.file.name, self.df,append=papp,compression=self.pq_compression,has_nulls=self.pq_hasnulls,write_index=self.pq_writeindex,file_scheme="simple",object_encoding=self.pq_objectencoding,times=self.pq_times,row_group_offsets=self.pq_rowgroupoffset)
             # initialize new data frame for new row group
             self._reset_rowgroup()
 
